Discover Packages
github.com/dberstein/recanati-notifier
deliver
package
Version:
v0.0.0-...-d075b32
Opens a new window with list of versions in this module.
Published: Oct 21, 2024
License: MIT
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func Daily(db *sql .DB , maxFailedAttempts int )
func Hourly(db *sql .DB , maxFailedAttempts int )
func Immediate(db *sql .DB , maxFailedAttempts int )
func Loop(db *sql .DB , maxFailedAttempts int )
type Delivery struct {
Id int `json:"id"`
Ntype int `json:"ntype"`
Type string `json:"type"`
Attempt int `json:"attempt"`
Target string `json:"target"`
Subject string `json:"subject"`
Body string `json:"body"`
Status bool `json:"status"`
}
type DeliveryStatus struct {
Id int `json:"id"`
Status bool `json:"status"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.